@@ -19,7 +19,7 @@
 #'     x = unemploy_rate,
 #'     y = psavert,
 #'     x_label = "Unemployment rate",
-#'     y_expand_limits = 0,
+#'     y_limits_include = 0,
 #'     y_label = "Personal savings rate",
 #'   )
 #'
@@ -49,7 +49,7 @@ gg_path <- function(data = NULL,
                     mapping = NULL,
                     x_breaks = NULL, x_breaks_n = NULL, 
                     x_expand = NULL,
-                    x_expand_limits = NULL,
+                    x_limits_include = NULL,
                     x_label = NULL, x_labels = NULL, 
                     
                     
@@ -58,7 +58,7 @@ gg_path <- function(data = NULL,
                     x_sec_axis = ggplot2::waiver(), x_symmetric = NULL, x_transform = NULL,
                     y_breaks = NULL, y_breaks_n = NULL,
                     y_expand = NULL,
-                    y_expand_limits = NULL,
+                    y_limits_include = NULL,
                     y_label = NULL, y_labels = NULL,
                      y_position = "left",
                     y_sec_axis = ggplot2::waiver(),
@@ -67,7 +67,7 @@ gg_path <- function(data = NULL,
                     y_transform = NULL,
                     col_breaks = NULL, col_breaks_n = 5,
                     col_drop = FALSE,
-                    col_expand_limits = NULL,
+                    col_limits_include = NULL,
                     col_label = NULL, col_labels = NULL,
                     col_legend_ncol = NULL,
                     col_legend_nrow = NULL,
@@ -120,7 +120,7 @@ gg_path <- function(data = NULL,
     mapping = mapping,
     x_breaks = x_breaks,
     x_expand = x_expand,
-    x_expand_limits = x_expand_limits,
+    x_limits_include = x_limits_include,
     x_labels = x_labels,
     x_breaks_n = x_breaks_n,
     x_sec_axis = x_sec_axis,
@@ -129,7 +129,7 @@ gg_path <- function(data = NULL,
     x_transform = x_transform,
     y_breaks = y_breaks,
     y_expand = y_expand,
-    y_expand_limits = y_expand_limits,
+    y_limits_include = y_limits_include,
     y_labels = y_labels,
     y_breaks_n = y_breaks_n,
     y_sec_axis = y_sec_axis,
@@ -138,7 +138,7 @@ gg_path <- function(data = NULL,
     y_transform = y_transform,
     col_breaks = col_breaks,
     col_drop = col_drop,
-    col_expand_limits = col_expand_limits,
+    col_limits_include = col_limits_include,
     col_labels = col_labels,
     col_legend_ncol = col_legend_ncol,
     col_legend_nrow = col_legend_nrow,
