@@ -14,7 +14,7 @@ test_that(test_name, {
       x = flipper_length_mm,
       y = body_mass_g,
       x_breaks = scales::breaks_width(15),
-      x_expand_limits = 250,
+      x_limits_include = 250,
       x_labels = scales::label_currency(),
       x_expand = c(0.5, 0.5),
       x_position = "top",
@@ -34,7 +34,7 @@ test_that(test_name, {
       x = flipper_length_mm,
       y = body_mass_g,
       y_breaks = scales::breaks_width(1000),
-      y_expand_limits = 7000,
+      y_limits_include = 7000,
       y_labels = scales::label_currency(),
       y_expand = c(0.1, 0.1),
       y_position = "right",
@@ -54,13 +54,13 @@ test_that(test_name, {
       x = flipper_length_mm,
       y = body_mass_g,
       x_breaks = scales::breaks_width(15),
-      x_expand_limits = 250,
+      x_limits_include = 250,
       x_labels = scales::label_currency(),
       x_expand = c(0.5, 0.5),
       x_position = "top",
       x_label = "Blah",
       y_breaks = scales::breaks_width(1000),
-      y_expand_limits = 7000,
+      y_limits_include = 7000,
       y_labels = scales::label_currency(),
       y_expand = c(0.1, 0.1),
       y_position = "right",
