@@ -16,9 +16,6 @@ test_that(test_name, {
     theme_axis_ticks_rm = FALSE,
     theme_panel_grid_rm = FALSE
   )
-  set_geom_font()
-
-  set_geom_reference_line()
 
   p <- penguins |>
     mutate(across(sex, \(x) stringr::str_to_sentence(x))) |>
@@ -42,9 +39,9 @@ test_that(test_name, {
     colour = red,
   )
 
-  set_geom_font(colour = teal)
+  update_geom_defaults("text", aes(colour = teal))
 
-  set_geom_reference_line(colour = teal)
+  update_geom_defaults("vline", aes(colour = teal))
 
   p <- penguins |>
     mutate(across(sex, \(x) stringr::str_to_sentence(x))) |>
@@ -67,9 +64,9 @@ set_blanket(
   col_palette_c = c(navy, purple, red, orange)
 )
 
-set_geom_font(colour = "red", size = 15 / 2.83505)
+update_geom_defaults("text", aes(colour = "red", size = 15 / 2.83505))
 
-set_geom_reference_line(colour = "red", linewidth = 5)
+update_geom_defaults("vline", aes(colour = "red", linewidth = 5))
 
 ###
 test_name <- "3"
